@@ -4,13 +4,14 @@
 #' @param csa (Optional) The CSA objects
 #' @param collaterals (Optional) The collaterals Objects
 #' @param simplified (optional) When TRUE, collaterals will be ignored as per the simplified & OEM approach
+#' @param ignore_margin (optional) if TRUE, the margin agreement workflow will be turned off
 #' @return The replacement Cost and the sum of the MtMs
 #' @export
 #' @author Tasos Grivas <tasos@@openriskcalculator.com>
 #' @references Regulation (EU) 2019/876 of the European Parliament and of the Council of 20 May 2019
 #' http://data.europa.eu/eli/reg/2019/876/oj
 
-CalcRC <- function(trades, csa, collaterals, simplified)  {
+CalcRC <- function(trades, csa, collaterals, simplified,ignore_margin=FALSE)  {
   
   V <- sum(sapply(trades, function(x) x$MtM))
   
@@ -51,9 +52,11 @@ CalcRC <- function(trades, csa, collaterals, simplified)  {
     {
       V_C = V
       RC  <- max(V_C, thres_cpty + MTA_cpty,0)
+      if(ignore_margin) RC  <- max(V_C, 0)
     }else{
       V_C <- V - current_collateral
       RC  <- max(V_C, thres_cpty + MTA_cpty- IM_cpty,0)
+      if(ignore_margin) RC  <- max(V_C, 0)
     }
     }else
     {
@@ -62,5 +65,5 @@ CalcRC <- function(trades, csa, collaterals, simplified)  {
     }
   }
   
-return(list("V_C"=V_C,"RC"=RC))
+return(list("V_C"=V_C,"RC"=RC,"V"=V))
 }
\ No newline at end of file
